@@ -2,10 +2,11 @@ package Sweet::Home;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.1';
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -23,62 +24,34 @@ Sweet::Home - Dir, File, HomeDir, and other sweet classes
 
     my $dir = Sweet::Dir->new(path => '/path/to/mydir');
 
-    $dir->is_a_directory or $dir->create;
+    $dir->is_a_directory || $dir->create;
 
     my $dir2 = $dir->sub_dir('foo');
 
     $dir2->create;
 
-    say $dir2; # /path/to/mydir/foo
-
     my $file = $dir2->file('bar');
 
-    say $file; # /path/to/mydir/foo/bar
-
 =head1 DESCRIPTION
 
 Nothing is better than feel at home. Where is the home? The home is where I can feel comfortable (cit. Jovanotti).
 
 This package provides a set of features to make you feel comfortable when working with files and folders.
 
-It is just syntactic sugar on top of packages like L<File::Basename>, L<File::Copy>, L<File::HomeDir>, L<File::Path>, L<File::Remove>, L<File::Spec>, etc.
-
-=head1 CODE COVERAGE
-
-Code coverage metrics report available L<here|http://g14n.info/Sweet-Home-pm/code/coverage.html>
+It is just syntactic sugar on top of packages like L<'File::Basename'>, L<'File::Copy'>, L<'File::HomeDir'>, L<'File::Path'>, L<'File::Remove'>, L<'File::Spec'>, etc.
 
 =head1 CLASSES
 
 =over 4
 
-=item L<Sweet::DatabaseConnection>
-
 =item L<Sweet::Dir>
 
 =item L<Sweet::File>
 
-=item L<Sweet::File::DSV>
-
-=item L<Sweet::File::CSV>
-
-=item L<Sweet::File::Semaphore>
-
 =item L<Sweet::HomeDir>
 
-=item L<Sweet::Now>
-
-=item L<Sweet::Schema>
-
-=item L<Sweet::SFTP>
-
 =back
 
-=begin HTML
-
-<img src="http://g14n.info/Sweet-Home-pm/dia/Sweet-Home.svg" alt="Class diagram" />
-
-=end HTML
-
 =head1 COPYRIGHT AND LICENSE
 
     This software is copyright (c) 2014 by G. Casati.
